summaryrefslogtreecommitdiff
path: root/cesar/ce/rx/bitloading/src/export_ce_rx_param.py
diff options
context:
space:
mode:
Diffstat (limited to 'cesar/ce/rx/bitloading/src/export_ce_rx_param.py')
-rw-r--r--cesar/ce/rx/bitloading/src/export_ce_rx_param.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/cesar/ce/rx/bitloading/src/export_ce_rx_param.py b/cesar/ce/rx/bitloading/src/export_ce_rx_param.py
index fa23480d17..39de6c2a73 100644
--- a/cesar/ce/rx/bitloading/src/export_ce_rx_param.py
+++ b/cesar/ce/rx/bitloading/src/export_ce_rx_param.py
@@ -1,12 +1,12 @@
#!/usr/bin/env python
# Get ce_rx_param.h file copy it in a new file ce_rx_param_tns_av.txt
# add in this file current git branch name.
import sys, subprocess, os
ce_rx_param_path = sys.path[0]+ '/../../ce_rx_param.h'
-ce_rx_param_path_tns = sys.path[0]+ '/../../ce_rx_param_tns_av.txt'
+ce_rx_param_path_tns = sys.path[0]+ '/../../ce_rx_param_tns_eoc.txt'
# Get current branch branch name
pr = subprocess.Popen(['git', 'describe'], cwd=os.path.dirname('./'),
@@ -1,12 +1,12 @@
#!/usr/bin/env python
-# Get ce_rx_param.h file copy it in a new file ce_rx_param_tns_av.txt
+# Get ce_rx_param.h file copy it in a new file ce_rx_param_tns_eoc.txt
# add in this file current git branch name.
import sys, subprocess, os